function [fp,tp] = runme(I1,I2,H)
    I1_gray = myrgb2gray(I1);
    I2_gray = myrgb2gray(I2);
    [locs1,desc1] = runSift(I1_gray);
    [locs2,desc2] = runSift(I2_gray);
    fprintf('Matching features...\n');
    [indices,distances] = getMatchesSlow(desc1,desc2,2); % call to your matching routine
    drawMatches(I1,locs1(:,1),locs1(:,2),I2,locs2(:,1),locs2(:,2),indices,distances,0.6,H);
    [fp,tp] = getROCCurve(locs1(:,1),locs1(:,2),locs2(:,1),locs2(:,2),indices,distances,H);
end

function [locs,descriptors] = runSift(I)
    [rows, cols] = size(I); 

    % Convert into PGM imagefile, readable by "keypoints" executable
    f = fopen('tmp.pgm', 'w');
    if f == -1
        error('Could not create file tmp.pgm.');
    end
    fprintf(f, 'P5\n%d\n%d\n255\n', cols, rows);
    fwrite(f, I', 'uint8');
    fclose(f);

    % Call keypoints executable
    if isunix
        command = '!./sift ';
    else
        command = '!siftWin32 ';
    end
    command = [command ' <tmp.pgm >tmp.key'];
    eval(command);

    % Open tmp.key and check its header
    g = fopen('tmp.key', 'r');
    if g == -1
        error('Could not open file tmp.key.');
    end
    [header, count] = fscanf(g, '%d %d', [1 2]);
    if count ~= 2
        error('Invalid keypoint file beginning.');
    end
    num = header(1);
    len = header(2);
    if len ~= 128
        error('Keypoint descriptor length invalid (should be 128).');
    end

    % Creates the two output matrices (use known size for efficiency)
    locs = double(zeros(num, 4));
    descriptors = double(zeros(num, 128));

    % Parse tmp.key
    for i = 1:num
        [vector, count] = fscanf(g, '%f %f %f %f', [1 4]); %row col scale ori
        if count ~= 4
            error('Invalid keypoint file format');
        end
        locs(i, :) = vector(1, :);
    
        [descrip, count] = fscanf(g, '%d', [1 len]);
        if (count ~= 128)
            error('Invalid keypoint file value.');
        end
        % Normalize each input vector to unit length
        descrip = descrip / sqrt(sum(descrip.^2));
        descriptors(i, :) = descrip(1, :);
    end
    fclose(g);
    descriptors = descriptors';
    locs = locs(:,1:2) + 1; % convert to MATLAB coordinates
end
